****************************************************************************
**		File name:	within country analysis
**		Authors: 	Liran Harsgor, Orit Kedar, Raz Sheinerman
**		Date: 		Final version: June 8 2015
**		Purpose: 	Produce Tables A2-A4 (and the anlysis for Table A5) as well as 
**					Figure 3 and Figure A1 + robustness checks
**		Input:		PDL_21C_ready.dta			                                                                 
*****************************************************************************

use "PDL_21C_ready.dta", clear
capture log using "within_a.log", replace

* user-written command, used below
ssc install outreg2

********************************************************************************************
*** 1. Calculate district-party vote share (dpvs) and district-party seat share (dpss) ***
*** then calculate cumulative district-party vote-share and seat-share (cdpvs, cdpss)
********************************************************************************************

gen lndm=ln(dm)

gen dpvs=votes/tvc
gen dpss=seats/tsc
label var dpvs "district-party vote share"
label var dpss "district-party seat share"

* When dpss=0, CR equals zero, so to differentiate among different cases
* turn dpss to 0.0000001.
replace dpss=0.0000001 if dpss==0

* calculate conversion ratio (CR=seat-share/vote-share)
gen cr = dpss/dpvs
label var cr "Conversion Ratio"

**************************************************************
*** 2a. DM, party ideological placement, and their interaction on CR
**************************************************************
* interact ln(dm) with party ideology
gen dmpl=lndm*par_ide

save "21C_for_interactions", replace
use "21C_for_interactions", clear 

* all DPR's excluding Malta and Italy
levelsof country_c if country_unique==1 & ctry_dpr==1 & country_c!=109 ///
& country_c!=120, local(countries)

foreach i of local countries {
	use "21C_for_interactions", clear
	keep if country_c==`i'
	sum lndm
	gen max_lndm= r(max)
	gen min_lndm= r(min)
	sum dm
	local maxdm= r(max)
	local mindm= r(min)
	levelsof country, local(country_name)
	
	reg cr par_ide lndm dmpl, cluster(district_c)
	** ROBUSTNESS CHECKS  (the outreg command below saves results of the model
	** above)**
	*reg cr par_ide lndm dmpl, cluster(party_c)
	*xtset party_c
	*xtreg cr par_ide lndm dmpl, fe cluster(party_c)
	*xtset party_c
	*xtreg cr par_ide lndm dmpl, fe
	*xtset party_c
	*xtreg cr par_ide lndm dmpl, fe cluster(district_c) nonest
	
	outreg2 using TableA2.doc, stats(coef se pval) noast dec(3) rdec(2) append ///
	ctitle(`country_name')
	
	*** Figure 3. Based on code provided by Brambor et. al (2006)
	
	generate MV= min_lndm + ((max_lndm- min_lndm)*(_n-1))/_N
	
	* save regression results of coefficients and their SE's
	matrix b=e(b)
	matrix V=e(V)
	scalar b1=b[1,1]
	scalar b2=b[1,2]
	scalar b3=b[1,3]
	scalar varb1=V[1,1]
	scalar varb2=V[2,2]
	scalar varb3=V[3,3]
	scalar covb1b3=V[1,3]
	scalar covb2b3=V[2,3]

	* prepare effect line and 95% confidence intervals 
	gen conb= b1+b3*MV if _n < _N 
	gen conse= sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n < _N
	gen a= 1.96*conse
	gen upper= conb+a
	gen lower= conb-a
	gen yline=0
	
	local title "`country_name'(`mindm'-`maxdm')"
	* graph effect line and confidence intervals counrty by country
	graph twoway line conb  MV, clwidth(medium) clcolor(blue) clcolor(black) ///
        ||   line upper  MV, clpattern(dash) clwidth(thin) clcolor(black) ///
        ||   line lower  MV, clpattern(dash) clwidth(thin) clcolor(black) ///
            , legend(off) yline(0, lwidth(thin) lcolor(gray))   ///
			graphregion(fcolor(white) lcolor(white))  ///
			title(`title', size(5.9)) ///
            xtitle( "ln(DM)", size(3)  ) ///
            ytitle("Effect of partyLR on CR", size(3)) yla(,nogrid) ///
            scheme(s2mono) graphregion(fcolor(white))

	graph save "int_`i'", replace
}


**************************************************************
*** 2b. Pooled model: DM, party ideological placement, and their interaction on CR
**************************************************************

use "21C_for_interactions", clear
	* keep districted PR's but exclude Italy and Malta
	drop if ctry_dpr!=1 | country_c==120 | country_c==109
	sum lndm
	gen max_lndm= r(max)
	gen min_lndm= r(min)
	* Run the model (FE on country, cluster SE's on district). The outreg command 
	* below reports this model
	xtset country_c
	xtreg cr par_ide lndm dmpl, fe cluster(district_c) nonest
	
	* Robustness checks
	*xtreg  cr par_ide lndm dmpl, fe
	*xtreg  cr par_ide lndm dmpl, fe cluster(country_c)
	*xtreg  cr par_ide lndm dmpl, fe cluster(party_c) nonest
	
	outreg2 using TableA2.doc, stats(coef se pval) noast dec(3) rdec(2) append ctitle("Pooled")
	
	* graphics is identical to country models (2a). See comments above. 
	
	generate MV= min_lndm + ((max_lndm- min_lndm)*(_n-1))/_N
	
	matrix b=e(b)
	matrix V=e(V)
	scalar b1=b[1,1]
	scalar b2=b[1,2]
	scalar b3=b[1,3]
	scalar varb1=V[1,1]
	scalar varb2=V[2,2]
	scalar varb3=V[3,3]
	scalar covb1b3=V[1,3]
	scalar covb2b3=V[2,3]

	gen conb= b1+b3*MV if _n < _N 
	gen conse= sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n < _N
	gen a= 1.96*conse
	gen upper= conb+a
	gen lower= conb-a
	gen yline=0

	graph twoway line conb  MV, clwidth(medium) clcolor(blue) clcolor(black) ///
        ||   line upper  MV, clpattern(dash) clwidth(thin) clcolor(black) ///
        ||   line lower  MV, clpattern(dash) clwidth(thin) clcolor(black) ///
            , legend(off) yline(0, lwidth(thin) lcolor(gray))   ///
			graphregion(fcolor(white) lcolor(white))  ///
			title("Pooled", size(5.9)) ///
            xtitle( "ln(DM)", size(3)  ) ///
            ytitle("Effect of partyLR on CR", size(3)) yla(,nogrid) ///
            scheme(s2mono) graphregion(fcolor(white))
	graph save "int_pooled", replace

	*******
graph combine "int_108" "int_106" "int_113" "int_115" ///
"int_111" "int_112" "int_107" "int_103" "int_114" ///
"int_104" "int_102" "int_110" "int_pooled", col(5) ///
scheme(s2mono) graphregion(fcolor(white))
			
*graph save "J:\share\Disproportional PR\Data and codes\Revisions final\graphs\int_all", replace
graph save "Figure 3"

drop max_lndm min_lndm MV conb conse a upper lower yline 

**************************************************************	
*** 3. Table A3. Voter inequality and DM regression (abs(1-CR)=b0+ b1(ln(DM))	
**************************************************************	

use "21C_for_interactions", clear

* Calculate dependent variable
gen crd= abs(1-cr)

* 3a. run country-by-country (districted PRs) regressions. Exclude Malta.
levelsof country_c if country_unique==1 & ctry_dpr==1 & country_c!=120, local(countries)
foreach i of local countries {
	levelsof country if country_c==`i', local(cntry_name)
	reg crd lndm if country_c==`i', cluster(district_c)
	outreg2 using TableA3.doc, stats(coef se pval) noast dec(3) rdec(2) append ctitle(`cntry_name')
}

**** 3b. Pooled model ****
* including country fixed effects and standard errors clustered by districts  
xtset country_c
xtreg crd lndm if country_c!=120 & ctry_dpr==1 , fe cluster(district_c) nonest
outreg2 using TableA3.doc, stats(coef se pval) noast dec(3) rdec(2) append ctitle("Pooled")

**************************************************************
*** 4. Table A4 and Figure A1. DM, party size, and their interaction on CR
**************************************************************

* generate interaction
gen pd=lndm*dvs

save "21C_for_interactions", replace
use "21C_for_interactions", clear 

* 4a. Run country-by-country model and graph it. Structure of code is identical to 
* Section 2. See comments above. 

levelsof country_c if country_unique==1 & ctry_dpr==1 & country_c!=120, local(countries)
foreach i of local countries {
	use "21C_for_interactions", clear
	keep if country_c==`i'
	sum lndm
	gen max_lndm= r(max)
	gen min_lndm= r(min)
	sum dm
	local maxdm= r(max)
	local mindm= r(min)
	levelsof country, local(country_name)
	reg cr dvs lndm pd, cluster(district_c)
	outreg2 using TableA4.doc, stats(coef se pval) noast dec(3) rdec(2) append ctitle(`country_name')
	
	* graph
	generate MV= min_lndm + ((max_lndm- min_lndm)*(_n-1))/_N 
	matrix b=e(b)
	matrix V=e(V)
	scalar b1=b[1,1]
	scalar b2=b[1,2]
	scalar b3=b[1,3]
	scalar varb1=V[1,1]
	scalar varb2=V[2,2]
	scalar varb3=V[3,3]
	scalar covb1b3=V[1,3]
	scalar covb2b3=V[2,3]

	gen conb= b1+b3*MV if _n < _N 
	gen conse= sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n < _N
	gen a= 1.96*conse
	gen upper= conb+a
	gen lower= conb-a
	gen yline=0
	
	local title "`country_name'(`mindm'-`maxdm')"

	graph twoway line conb  MV, clwidth(medium) clcolor(blue) clcolor(black) ///
        ||   line upper  MV, clpattern(dash) clwidth(thin) clcolor(black) ///
        ||   line lower  MV, clpattern(dash) clwidth(thin) clcolor(black) ///
            , legend(off) yline(0, lcolor(black))   ///
			graphregion(fcolor(white) lcolor(white)) ///
			title(`title', size(4)) ///
             xtitle( "ln(dm)", size(3)) ///
             ytitle("Effect of partyVS on CR", size(3)) yla(,nogrid) ///
             scheme(s2mono) graphregion(fcolor(white))
			 
	graph save "inter_`i'", replace
}



* 4b. Run Pooled model and graph it. Structure of code is identical to 
* Section 2. See comments above. 

	use "21C_for_interactions", clear
	drop if ctry_dpr!=1 | country_c==120
	
	sum lndm
	gen max_lndm= r(max)
	gen min_lndm= r(min)
	
	xtset country_c
	xtreg  cr dvs lndm pd, fe cluster(country_c)
	outreg2 using TableA4.doc, stats(coef se pval) noast dec(3) rdec(2) append ctitle("Pooled")

	*Graph
	generate MV= min_lndm + ((max_lndm- min_lndm)*(_n-1))/_N
	matrix b=e(b)
	matrix V=e(V)
	scalar b1=b[1,1]
	scalar b2=b[1,2]
	scalar b3=b[1,3]
	scalar varb1=V[1,1]
	scalar varb2=V[2,2]
	scalar varb3=V[3,3]
	scalar covb1b3=V[1,3]
	scalar covb2b3=V[2,3]

	gen conb= b1+b3*MV if _n < _N 
	gen conse= sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n < _N
	gen a= 1.96*conse
	gen upper= conb+a
	gen lower= conb-a
	gen yline=0

	graph twoway line conb  MV, clwidth(medium) clcolor(blue) clcolor(black) ///
        ||   line upper  MV, clpattern(dash) clwidth(thin) clcolor(black) ///
        ||   line lower  MV, clpattern(dash) clwidth(thin) clcolor(black) ///
            , legend(off) yline(0, lcolor(black))   ///
			graphregion(fcolor(white) lcolor(white))  ///
			title("Pooled", size(4)) ///
            xtitle( "ln(DM)", size(3)) ///
            ytitle("Effect of partyVS on CR", size(3)) yla(,nogrid) ///
            scheme(s2mono) graphregion(fcolor(white))

	graph save "inter_pooled", replace

	*******

graph combine "inter_108" "inter_106" "inter_113" "inter_115" "inter_111" ///
"inter_112" "inter_107" "inter_103" "inter_114" "inter_104" "inter_102" ///
"inter_110" "inter_109" "inter_pooled", col(5) ///
            scheme(s2mono) graphregion(fcolor(white))

*graph save "J:\share\Disproportional PR\Data and codes\Revisions final\graphs\DM_CR_VS", replace
graph save "Figure A1"
drop max_lndm min_lndm MV conb conse a upper lower yline 


***************************************************************
** 5. Repeat section 2 with Chapel Hill Data for party placements (Robustness section)
*************************************************************

* correlations between datasets 
pwcorr par_ide_ch par_ide if party_unique==1, sig obs
by country, sort: pwcorr par_ide_ch par_ide if party_unique==1, sig obs


* Construct interaction 
gen dmpl_ch=lndm*par_ide_ch

save "21C_for_interactions", replace
use "21C_for_interactions", clear 

*5a. Country-by-country analysis and graph
* exclude countries for which there are no relevant data in the CH dataset. 
levelsof country_c if country_unique==1 & ctry_dpr==1 & country_c!=107 ///
& country_c!=110 & country_c!=111 & country_c!=115 & country_c!=120, local(countries)

foreach i of local countries {
	use "21C_for_interactions", clear
	keep if country_c==`i'
	sum lndm
	gen max_lndm= r(max)
	gen min_lndm= r(min)
	sum dm
	local maxdm= r(max)
	local mindm= r(min)
	levelsof country, local(country_name)
	
	reg cr par_ide_ch lndm dmpl_ch, cluster(district_c)
	*Robustness
	*reg cr par_ide lndm dmpl, cluster(party_c)
	*xtset party_c
	*xtreg cr par_ide lndm dmpl, fe cluster(party_c)
	*xtset party_c
	*xtreg cr par_ide lndm dmpl, fe
	*xtset party_c
	*xtreg cr par_ide lndm dmpl, fe cluster(district_c) nonest
	outreg2 using TableA2_ch.doc, stats(coef se pval) noast dec(3) rdec(2) append ctitle(`country_name')
	
	*Graph
	generate MV= min_lndm + ((max_lndm- min_lndm)*(_n-1))/_N
	matrix b=e(b)
	matrix V=e(V)
	scalar b1=b[1,1]
	scalar b2=b[1,2]
	scalar b3=b[1,3]
	scalar varb1=V[1,1]
	scalar varb2=V[2,2]
	scalar varb3=V[3,3]
	scalar covb1b3=V[1,3]
	scalar covb2b3=V[2,3]

	gen conb= b1+b3*MV if _n < _N 
	gen conse= sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n < _N
	gen a= 1.96*conse
	gen upper= conb+a
	gen lower= conb-a
	gen yline=0

	local title "`country_name'(`mindm'-`maxdm')"
	
	graph twoway line conb  MV, clwidth(medium) clcolor(blue) clcolor(black) ///
        ||   line upper  MV, clpattern(dash) clwidth(thin) clcolor(black) ///
        ||   line lower  MV, clpattern(dash) clwidth(thin) clcolor(black) ///
            , legend(off) yline(0, lwidth(thin) lcolor(gray))   ///
			graphregion(fcolor(white) lcolor(white))  ///
			title(`title', size(5.9)) ///
            xtitle( "ln(DM)", size(3)  ) ///
            ytitle("Effect of partyLR on CR", size(3)) yla(,nogrid) ///
            scheme(s2mono) graphregion(fcolor(white))

	graph save "int_`i'_ch", replace
}



*5b. Pooled analysis and graph 

use "21C_for_interactions", clear
	drop if ctry_dpr!=1 | country_c==107 ///
	| country_c==110 | country_c==111 | country_c==115 | country_c==120
	sum lndm
	gen max_lndm= r(max)
	gen min_lndm= r(min)
	
	xtset country_c
	xtreg  cr par_ide_ch lndm dmpl_ch, fe cluster(district_c) nonest
	*xtreg  cr par_ide lndm dmpl, fe
	*xtreg  cr par_ide lndm dmpl, fe cluster(country_c)
	*xtreg  cr par_ide lndm dmpl, fe cluster(party_c) nonest
	outreg2 using TableA2_ch.doc, stats(coef se pval) noast dec(3) rdec(2) append ctitle("Pooled")
	
	*Graph
	generate MV= min_lndm + ((max_lndm- min_lndm)*(_n-1))/_N
	matrix b=e(b)
	matrix V=e(V)
	scalar b1=b[1,1]
	scalar b2=b[1,2]
	scalar b3=b[1,3]
	scalar varb1=V[1,1]
	scalar varb2=V[2,2]
	scalar varb3=V[3,3]
	scalar covb1b3=V[1,3]
	scalar covb2b3=V[2,3]

	gen conb= b1+b3*MV if _n < _N 
	gen conse= sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV) if _n < _N
	gen a= 1.96*conse
	gen upper= conb+a
	gen lower= conb-a
	gen yline=0

	graph twoway line conb  MV, clwidth(medium) clcolor(blue) clcolor(black) ///
        ||   line upper  MV, clpattern(dash) clwidth(thin) clcolor(black) ///
        ||   line lower  MV, clpattern(dash) clwidth(thin) clcolor(black) ///
            , legend(off) yline(0, lwidth(thin) lcolor(gray))   ///
			graphregion(fcolor(white) lcolor(white))  ///
			title("Pooled", size(5.9)) ///
            xtitle( "ln(DM)", size(3)  ) ///
            ytitle("Effect of partyLR on CR", size(3)) yla(,nogrid) ///
            scheme(s2mono) graphregion(fcolor(white))

	graph save "int_pooled_ch", replace
	
	*******
	
graph combine "int_108_ch" "int_106_ch" "int_113_ch" ///
"int_112_ch" "int_103_ch" "int_114_ch" ///
"int_104_ch" "int_102_ch" "int_109_ch" ///
"int_pooled_ch", col(4) ///
scheme(s2mono) graphregion(fcolor(white))

graph save "int_all_ch", replace
			
****************************************************************************			
*** 6. Table A5. Repeat Section 2 analysis with HLM (rather than clustering)
****************************************************************************

use "21C_for_interactions", clear 

levelsof country_c if country_unique==1 & ctry_dpr==1 & country_c!=109 & country_c!=120, local(countries)

foreach i of local countries {
	use "21C_for_interactions", clear
	keep if country_c==`i'
	display "********"
	display country[_n]
	display "********"
	levelsof country, local(country_name)
	xtmixed  cr par_ide lndm dmpl  || _all: R.party_c || district_c:
}
* Unlike other tables in this study, because of dimensions of this table, 
* we produce Table A5 manually from the analysis printout. 

log close

