****************************************************************************
**		File name:	within country descriptive
**		Authors: 	Liran Harsgor, Orit Kedar, Raz Sheinerman
**		Date: 		Final version: June 8 2015
**		Purpose: 	Create Lorenz curves and Representatioanl Inequlity (RI) index 
**					for all countries					 										
**		Input:		PDL_21C_ready.dta
*****************************************************************************

use "PDL_21C_ready.dta", clear
capture log using "within_d.log", replace

*** 1. Calculate district-party vote-share (dpvs) and district-party seat share (dpss).
*** Also calculate cumulative district-party vote-share and seat-share (cdpvs, cdpss)

gen lndm=ln(dm)

gen dpvs=votes/tvc
gen dpss=seats/tsc
label var dpvs "district-party vote share"
label var dpss "district-party seat share"

* When dpss=0, CR equals zero, so to differentiate among different cases
* turn dpss to 0.0000001. Needed for future analyses only. 
replace dpss=0.0000001 if dpss==0

* calculate conversion ratio (CR=seat-share/vote-share)
gen cr = dpss/dpvs
label var cr "Conversion Ratio"

*** Preparation for plotting the curve
* for each country sort cr in ascending order 
sort country_c cr
* Calculate cumulative district-party vote-share (dpvs) within each country 
by country_c (cr), sort: gen cdpvs=sum(dpvs)
* Calculate cumulative district-party seat-share (dpss) within each country
by country_c (cr), sort: gen cdpss=sum(dpss)

label var cdpvs "cumulative district-party vote share"
label var cdpss "cumulative district-party seat share"

*** 2. Calculate RI index for each country

* 	 				
*	 |			  /     .
* 	 |			 /      
*	 |			/       .
*	 |		   /       
*	 |		  /       .
*	 |       /       
*	 |      /       .
*	 |     /       
*	 |    /      .
*	 |   /     . (cdpvs[_n],cdpss[_n])
*	 |  /      |
*	 | /   .   |
*	 |/_.__|___|______________________
*	    [_n-1]  (cdpvs[_n],0)
*
***********************************************************

* In order to calculate RI we calculate the area between the 45-degree line and 
* the curve ("the belly"). We do so by: 1. Calculate the area under the "belly"
* 2. Subtract this area from the triangle (which equals 0.5)
* RI = 2*"belly" area 
 
* (1) Calculate the area under the "belly"
* Calculate the area of the trapezoid between each two data points (see fig. above)
sort country_c cr
	by country_c: gen area = (cdpss[_n]+cdpss[_n-1])/2*(cdpvs[_n]-cdpvs[_n-1])  
	replace area = cdpss*cdpvs/2 if area == . /* for first trianlge*/

* Calculate the sum of all trapezoids
egen lorenzshadow= total (area), by (country_c)

* (2) Calculate RI = (2*"belly area")
gen gini= 2*(0.5 - lorenzshadow)

* Create a string var for note on graphs (rounding to second digit after decimal point)
gen gini_100 = gini*100
replace gini_100 = int(gini_100)+1 if abs(gini_100-int(gini_100)) > abs(gini_100-(int(gini_100)+1))
replace gini_100 = int(gini_100)
gen gini_st = string(gini_100/100)

label var gini "RI index"

****************************************
*** 3. Graphs ***
****************************************

* A.  Add observations of (0,0) in (cdpvs,cdpss) for each country  in order to 
* connect the scatters to the origins.

* Calculate number of observations in current dataset and add X new empty 
* observations, where X equals to the number of county/election observations (21)
local obs_original = _N
local all_obs = 21+_N
set obs `all_obs'

* Add to to each of the new empty observations unique country code
* Replace cdpvs and cdpss with 0
levelsof country_c, local(countries)
local j = `obs_original'+1
foreach i of local countries {
		replace country_c = `i' in `j'
		replace cdpss = 0 in `j'
		replace cdpvs = 0 in `j'
		local j = `j' + 1
}


* B. Lorenz graphs 

* gini_st: a string of two decimal digits (RI) to appear on the side of each graph 
* The levelsof gini_st command returns a local of a list of all gini_st values. 
* When combined with "if country_c==XXX" it returns only one RI value - the value 
* of RI in that country. We then use this local as a small box text in each country graph.

****   ****
* Belgium *
****   ****

levelsof gini_st if country_c==102, local(gini_legend) clean
twoway  scatter cdpss cdpvs if country_c==102, sort connect(l) msize(vsmall) aspectratio(1) ///
	|| function y=x, lc(black) ///
	graphregion(fcolor(white) lcolor(white)) ///
	title("Belgium", size(5 )) ///
	xtitle("Cum. vote-share", size(2.5)) /// 
	ytitle("Cum. seat-share", size(2.5)) yla(,nogrid)  ///
	legend(off) text(0.95 0.12 "RI `gini_legend'") 
	
	graph save "RI_lr_be_102.gph", replace

****   ****
* Denmark *
****   ****

levelsof gini_st if country_c==103, local(gini_legend) clean
twoway  scatter cdpss cdpvs if country_c==103  , sort connect(l) msize(vsmall) ms(oh) aspectratio(1) ///
	|| function y=x, lc(black) ///
	graphregion(fcolor(white) lcolor(white)) ///
	title("Denmark", size(5 )) ///
	xtitle("Cum. vote-share", size(2.5)) /// 
	ytitle("Cum. seat-share", size(2.5)) yla(,nogrid)  ///
	legend(off) text(0.95 0.12 "RI `gini_legend'") 
	
	graph save "RI_lr_dk_103.gph", replace
	
****   ****
* Finland *
****   ****

levelsof gini_st if country_c==104, local(gini_legend) clean
twoway  scatter cdpss cdpvs if country_c==104  , sort connect(l) msize(vsmall) ms(oh) aspectratio(1) ///
	|| function y=x, lc(black) ///
	graphregion(fcolor(white) lcolor(white)) ///
	title("Finland", size(5 )) ///
	xtitle("Cum. vote-share", size(2.5)) /// 
	ytitle("Cum. seat-share", size(2.5)) yla(,nogrid)  ///
	legend(off) text(0.95 0.12 "RI `gini_legend'") 
	
	graph save "RI_lr_fi_104.gph", replace
	
****   ****
* Greece *
****   ****

levelsof gini_st if country_c==106, local(gini_legend) clean
twoway  scatter cdpss cdpvs if country_c==106  , sort connect(l) msize(vsmall) ms(oh) aspectratio(1) ///
	|| function y=x, lc(black) ///
	graphregion(fcolor(white) lcolor(white)) ///
	title("Greece", size(5 )) ///
	xtitle("Cum. vote-share", size(2.5)) /// 
	ytitle("Cum. seat-share", size(2.5)) yla(,nogrid)  ///
	legend(off) text(0.95 0.12 "RI `gini_legend'") 
	
	graph save "RI_lr_gr_106.gph", replace
	
****   ****
* Iceland *
****   ****

levelsof gini_st if country_c==107, local(gini_legend) clean
twoway  scatter cdpss cdpvs if country_c==107  , sort connect(l) msize(vsmall) ms(oh) aspectratio(1) ///
	|| function y=x, lc(black) ///
	graphregion(fcolor(white) lcolor(white)) ///
	title("Iceland", size(5 )) ///
	xtitle("Cum. vote-share", size(2.5)) /// 
	ytitle("Cum. seat-share", size(2.5)) yla(,nogrid)  ///
	legend(off) text(0.95 0.12 "RI `gini_legend'") 
	
	graph save "RI_lr_is_107.gph", replace
	
****   ****
* Ireland *
****   ****

levelsof gini_st if country_c==108, local(gini_legend) clean
twoway  scatter cdpss cdpvs if country_c==108  , sort connect(l) msize(vsmall) ms(oh) aspectratio(1) ///
	|| function y=x, lc(black) ///
	graphregion(fcolor(white) lcolor(white)) ///
	title("Ireland", size(5 )) ///
	xtitle("Cum. vote-share", size(2.5)) /// 
	ytitle("Cum. seat-share", size(2.5)) yla(,nogrid)  ///
	legend(off) text(0.95 0.12 "RI `gini_legend'") 
	
	graph save "RI_lr_ie_108.gph", replace
	
****   ****
* Italy *
****   ****

levelsof gini_st if country_c==109, local(gini_legend) clean
twoway  scatter cdpss cdpvs if country_c==109  , sort connect(l) msize(vsmall) ms(oh) aspectratio(1) ///
	|| function y=x, lc(black) ///
	graphregion(fcolor(white) lcolor(white)) ///
	title("Italy", size(5 )) ///
	xtitle("Cum. vote-share", size(2.5)) /// 
	ytitle("Cum. seat-share", size(2.5)) yla(,nogrid)  ///
	legend(off) text(0.95 0.12 "RI `gini_legend'") 
	
	graph save "RI_lr_it_109.gph", replace
	
****   ****
* Luxemburg *
****   ****

levelsof gini_st if country_c==110, local(gini_legend) clean
twoway  scatter cdpss cdpvs if country_c==110  , sort connect(l) msize(vsmall) ms(oh) aspectratio(1) ///
	|| function y=x, lc(black) ///
	graphregion(fcolor(white) lcolor(white)) ///
	title("Luxemburg", size(5 )) ///
	xtitle("Cum. vote-share", size(2.5)) /// 
	ytitle("Cum. seat-share", size(2.5)) yla(,nogrid)  ///
	legend(off) text(0.95 0.12 "RI `gini_legend'") 
	
	graph save "RI_lr_lu_110.gph", replace

****   ****
* Norway *
****   ****

levelsof gini_st if country_c==111, local(gini_legend) clean
twoway  scatter cdpss cdpvs if country_c==111  , sort connect(l) msize(vsmall) ms(oh) aspectratio(1) ///
	|| function y=x, lc(black) ///
	graphregion(fcolor(white) lcolor(white)) ///
	title("Norway", size(5 )) ///
	xtitle("Cum. vote-share", size(2.5)) /// 
	ytitle("Cum. seat-share", size(2.5)) yla(,nogrid)  ///
	legend(off) text(0.95 0.12 "RI `gini_legend'") 
	
	graph save "RI_lr_no_111.gph", replace

****   ****
* Portugal *
****   ****

levelsof gini_st if country_c==112, local(gini_legend) clean
twoway  scatter cdpss cdpvs if country_c==112  , sort connect(l) msize(vsmall) ms(oh) aspectratio(1) ///
	|| function y=x, lc(black) ///
	graphregion(fcolor(white) lcolor(white)) ///
	title("Portugal", size(5 )) ///
	xtitle("Cum. vote-share", size(2.5)) /// 
	ytitle("Cum. seat-share", size(2.5)) yla(,nogrid)  ///
	legend(off) text(0.95 0.12 "RI `gini_legend'") 
	
	graph save "RI_lr_pt_112.gph", replace

****   ****
* Spain *
****   ****

levelsof gini_st if country_c==113, local(gini_legend) clean
twoway  scatter cdpss cdpvs if country_c==113  , sort connect(l) msize(vsmall) ms(oh) aspectratio(1) ///
	|| function y=x, lc(black) ///
	graphregion(fcolor(white) lcolor(white)) ///
	title("Spain", size(5 )) ///
	xtitle("Cum. vote-share", size(2.5)) /// 
	ytitle("Cum. seat-share", size(2.5)) yla(,nogrid)  ///
	legend(off) text(0.95 0.12 "RI `gini_legend'") 
	
	graph save "RI_lr_es_113.gph", replace

****   ****
* Sweden *
****   ****

levelsof gini_st if country_c==114, local(gini_legend) clean
twoway  scatter cdpss cdpvs if country_c==114  , sort connect(l) msize(vsmall) ms(oh) aspectratio(1) ///
	|| function y=x, lc(black) ///
	graphregion(fcolor(white) lcolor(white)) ///
	title("Sweden", size(5 )) ///
	xtitle("Cum. vote-share", size(2.5)) /// 
	ytitle("Cum. seat-share", size(2.5)) yla(,nogrid)  ///
	legend(off) text(0.95 0.12 "RI `gini_legend'") 
	
	graph save "RI_lr_se_114.gph", replace

****   ****
* Switzerland *
****   ****

levelsof gini_st if country_c==115, local(gini_legend) clean
twoway  scatter cdpss cdpvs if country_c==115  , sort connect(l) msize(vsmall) ms(oh) aspectratio(1)  ///
	|| function y=x, lc(black) ///
	graphregion(fcolor(white) lcolor(white)) ///
	title("Switzerland", size(5 )) ///
	xtitle("Cum. vote-share", size(2.5)) /// 
	ytitle("Cum. seat-share", size(2.5)) yla(,nogrid)  ///
	legend(off) text(0.95 0.12 "RI `gini_legend'") 
	
	graph save "RI_lr_ch_115.gph", replace

****   ****
* UK *
****   ****

levelsof gini_st if country_c==123, local(gini_legend) clean
twoway  scatter cdpss cdpvs if country_c==123  , sort connect(l) msize(vsmall) ms(oh) aspectratio(1)  ///
	|| function y=x, lc(black) ///
	graphregion(fcolor(white) lcolor(white)) ///
	title("UK", size(5 )) ///
	xtitle("Cum. vote-share", size(2.5)) /// 
	ytitle("Cum. seat-share", size(2.5)) yla(,nogrid)  ///
	legend(off) text(0.95 0.12 "RI `gini_legend'") 
	
	graph save "RI_lr_uk_123.gph", replace


****   ****
* Canada *
****   ****

levelsof gini_st if country_c==117, local(gini_legend) clean
twoway  scatter cdpss cdpvs if country_c==117  , sort connect(l) msize(vsmall) ms(oh) aspectratio(1)  ///
	|| function y=x, lc(black) ///
	graphregion(fcolor(white) lcolor(white)) ///
	title("Canada", size(5 )) ///
	xtitle("Cum. vote-share", size(2.5)) /// 
	ytitle("Cum. seat-share", size(2.5)) yla(,nogrid)  ///
	legend(off) text(0.95 0.12 "RI `gini_legend'") 
	
	graph save "RI_lr_ca_117.gph", replace

	
****   ****
* Malta *
****   ****

levelsof gini_st if country_c==120, local(gini_legend) clean
twoway  scatter cdpss cdpvs if country_c==120  , sort connect(l) msize(vsmall) ms(oh) aspectratio(1)  ///
	|| function y=x, lc(black) ///
	graphregion(fcolor(white) lcolor(white)) ///
	title("Malta", size(5 )) ///
	xtitle("Cum. vote-share", size(2.5)) /// 
	ytitle("Cum. seat-share", size(2.5)) yla(,nogrid)  ///
	legend(off) text(0.95 0.12 "RI `gini_legend'") 
	
	graph save "RI_lr_mt_120.gph", replace

****   ****
* Germany *
****   ****

levelsof gini_st if country_c==105, local(gini_legend) clean
twoway  scatter cdpss cdpvs if country_c==105  , sort connect(l) msize(vsmall) ms(oh) aspectratio(1)  ///
	|| function y=x, lc(black) ///
	graphregion(fcolor(white) lcolor(white)) ///
	title("Germany", size(5 )) ///
	xtitle("Cum. vote-share", size(2.5)) /// 
	ytitle("Cum. seat-share", size(2.5)) yla(,nogrid)  ///
	legend(off) text(0.95 0.12 "RI `gini_legend'") 
	
	graph save "RI_lr_de_105.gph", replace

****   ****
* Israel *
****   ****

levelsof gini_st if country_c==119, local(gini_legend) clean
twoway  scatter cdpss cdpvs if country_c==119  , sort connect(l) msize(vsmall) ms(oh) aspectratio(1)  ///
	|| function y=x, lc(black) ///
	graphregion(fcolor(white) lcolor(white)) ///
	title("Israel", size(5 )) ///
	xtitle("Cum. vote-share", size(2.5)) /// 
	ytitle("Cum. seat-share", size(2.5)) yla(,nogrid)  ///
	legend(off) text(0.95 0.12 "RI `gini_legend'") 
	
	graph save "RI_lr_il_119.gph", replace

****   ****
* the Netherlands *
****   ****

levelsof gini_st if country_c==121, local(gini_legend) clean
twoway  scatter cdpss cdpvs if country_c==121  , sort connect(l) msize(vsmall) ms(oh) aspectratio(1)  ///
	|| function y=x, lc(black) ///
	graphregion(fcolor(white) lcolor(white)) ///
	title("the Netherlands", size(5 )) ///
	xtitle("Cum. vote-share", size(2.5)) /// 
	ytitle("Cum. seat-share", size(2.5)) yla(,nogrid)  ///
	legend(off) text(0.95 0.12 "RI `gini_legend'") 
	
	graph save "RI_lr_nl_121.gph", replace

	
****   ****
* New Zealand 1993 *
****   ****

levelsof gini_st if country_c==132, local(gini_legend) clean
twoway  scatter cdpss cdpvs if country_c==132  , sort connect(l) msize(vsmall) ms(oh) aspectratio(1)  ///
	|| function y=x, lc(black) ///
	graphregion(fcolor(white) lcolor(white)) ///
	title("New Zealand 93", size(5)) ///
	xtitle("Cum. vote-share", size(2.5)) /// 
	ytitle("Cum. seat-share", size(2.5)) yla(,nogrid)  ///
	legend(off) text(0.95 0.12 "RI `gini_legend'") 
	
	graph save "RI_lr_nz93_132.gph", replace
	
****   ****
* New Zealand 1996 *
****   ****

levelsof gini_st if country_c==142, local(gini_legend) clean
twoway  scatter cdpss cdpvs if country_c==142  , sort connect(l) msize(vsmall) ms(oh) aspectratio(1)  ///
	|| function y=x, lc(black) ///
	graphregion(fcolor(white) lcolor(white)) ///
	title("New Zealand 96", size(5)) ///
	xtitle("Cum. vote-share", size(2.5)) /// 
	ytitle("Cum. seat-share", size(2.5)) yla(,nogrid)  ///
	legend(off) text(0.95 0.12 "RI `gini_legend'") 
	
	graph save "RI_lr_nz96_142.gph", replace
	
	
**** graph combine
* 21 countries graph sorted by avgDM:
graph combine  "RI_lr_uk_123" "RI_lr_nz93_132" "RI_lr_ca_117" "RI_lr_ie_108" ///
"RI_lr_mt_120" "RI_lr_gr_106" "RI_lr_es_113" "RI_lr_ch_115" "RI_lr_no_111" ///
"RI_lr_pt_112" "RI_lr_is_107" "RI_lr_se_114" "RI_lr_dk_103" "RI_lr_fi_104" ///
"RI_lr_be_102" "RI_lr_lu_110" "RI_lr_it_109" "RI_lr_il_119" "RI_lr_nz96_142" ///
"RI_lr_nl_121" "RI_lr_de_105" , ///
col(6) xsize(5.5) ysize(3) scheme(s2mono) graphregion(fcolor(white))

graph save  "RI_21.gph", replace


log close
